==> jc-1.4.0.tar.gz: javax/print/attribute/standard/PrinterStateReason.h <==
// public class javax.print.attribute.standard.PrinterStateReason

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class 4a4a9b3925fb969d javax_print_attribute_standard_PrinterStateReason

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_PrinterStateReason_H_
#define _JC_javax_print_attribute_standard_PrinterStateReason_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_PrinterStateReason$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$sub_refs	_jc_javax_print_attribute_standard_PrinterStateReason$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$sub_nonrefs	_jc_javax_print_attribute_standard_PrinterStateReason$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$refs	_jc_javax_print_attribute_standard_PrinterStateReason$refs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$nonrefs	_jc_javax_print_attribute_standard_PrinterStateReason$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$object	_jc_javax_print_attribute_standard_PrinterStateReason$object;

typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$fields_struct	_jc_javax_print_attribute_standard_PrinterStateReason$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReason$vmethods	_jc_javax_print_attribute_standard_PrinterStateReason$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReason$vtable	_jc_javax_print_attribute_standard_PrinterStateReason$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReason$vtype	_jc_javax_print_attribute_standard_PrinterStateReason$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrinterStateReason$fields_struct {
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*CONNECTING__5fTO__5fDEVICE;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*COVER__5fOPEN;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*DEVELOPER__5fEMPTY;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*DEVELOPER__5fLOW;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*DOOR__5fOPEN;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*FUSER__5fOVER__5fTEMP;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*FUSER__5fUNDER__5fTEMP;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*INPUT__5fTRAY__5fMISSING;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*INTERLOCK__5fOPEN;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*INTERPRETER__5fRESOURCE__5fUNAVAILABLE;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MARKER__5fSUPPLY__5fEMPTY;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MARKER__5fSUPPLY__5fLOW;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MARKER__5fWASTE__5fALMOST__5fFULL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MARKER__5fWASTE__5fFULL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MEDIA__5fEMPTY;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MEDIA__5fJAM;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MEDIA__5fLOW;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MEDIA__5fNEEDED;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MOVING__5fTO__5fPAUSED;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OPC__5fLIFE__5fOVER;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OPC__5fNEAR__5fEOL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OTHER;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OUTPUT__5fAREA__5fALMOST__5fFULL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OUTPUT__5fAREA__5fFULL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OUTPUT__5fTRAY__5fMISSING;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*PAUSED;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*SHUTDOWN;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*SPOOL__5fAREA__5fFULL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*STOPPED__5fPARTLY;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*STOPPING;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*TIMED__5fOUT;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*TONER__5fEMPTY;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*TONER__5fLOW;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrinterStateReason;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrinterStateReason$fields_struct _jc_javax_print_attribute_standard_PrinterStateReason$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrinterStateReason$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReason$object *, jint);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterStateReason$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReason$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrinterStateReason$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReason$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrinterStateReason$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrinterStateReason$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_PrinterStateReason$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterStateReason$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrinterStateReason$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReason$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReason$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_PrinterStateReason$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_PrinterStateReason$vmethods	javax_print_attribute_standard_PrinterStateReason;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrinterStateReason$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrinterStateReason$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterStateReason$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterStateReason$refs {
    _jc_javax_print_attribute_standard_PrinterStateReason$sub_refs	javax_print_attribute_standard_PrinterStateReason;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterStateReason$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterStateReason$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_PrinterStateReason$sub_nonrefs	javax_print_attribute_standard_PrinterStateReason;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrinterStateReason$object {
	_jc_javax_print_attribute_standard_PrinterStateReason$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrinterStateReason$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrinterStateReason$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrinterStateReason$vtype _jc_javax_print_attribute_standard_PrinterStateReason$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrinterStateReason, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrinterStateReason$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrinterStateReason_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/PrinterStateReason.h <==
// public class javax.print.attribute.standard.PrinterStateReason

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class 4a4a9b3925fb969d javax_print_attribute_standard_PrinterStateReason

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_PrinterStateReason_H_
#define _JC_javax_print_attribute_standard_PrinterStateReason_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_PrinterStateReason$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$sub_refs	_jc_javax_print_attribute_standard_PrinterStateReason$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$sub_nonrefs	_jc_javax_print_attribute_standard_PrinterStateReason$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$refs	_jc_javax_print_attribute_standard_PrinterStateReason$refs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$nonrefs	_jc_javax_print_attribute_standard_PrinterStateReason$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$object	_jc_javax_print_attribute_standard_PrinterStateReason$object;

typedef struct _jc_javax_print_attribute_standard_PrinterStateReason$fields_struct	_jc_javax_print_attribute_standard_PrinterStateReason$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReason$vmethods	_jc_javax_print_attribute_standard_PrinterStateReason$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReason$vtable	_jc_javax_print_attribute_standard_PrinterStateReason$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReason$vtype	_jc_javax_print_attribute_standard_PrinterStateReason$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrinterStateReason$fields_struct {
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*CONNECTING__5fTO__5fDEVICE;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*COVER__5fOPEN;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*DEVELOPER__5fEMPTY;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*DEVELOPER__5fLOW;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*DOOR__5fOPEN;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*FUSER__5fOVER__5fTEMP;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*FUSER__5fUNDER__5fTEMP;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*INPUT__5fTRAY__5fMISSING;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*INTERLOCK__5fOPEN;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*INTERPRETER__5fRESOURCE__5fUNAVAILABLE;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MARKER__5fSUPPLY__5fEMPTY;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MARKER__5fSUPPLY__5fLOW;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MARKER__5fWASTE__5fALMOST__5fFULL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MARKER__5fWASTE__5fFULL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MEDIA__5fEMPTY;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MEDIA__5fJAM;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MEDIA__5fLOW;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MEDIA__5fNEEDED;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*MOVING__5fTO__5fPAUSED;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OPC__5fLIFE__5fOVER;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OPC__5fNEAR__5fEOL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OTHER;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OUTPUT__5fAREA__5fALMOST__5fFULL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OUTPUT__5fAREA__5fFULL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*OUTPUT__5fTRAY__5fMISSING;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*PAUSED;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*SHUTDOWN;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*SPOOL__5fAREA__5fFULL;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*STOPPED__5fPARTLY;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*STOPPING;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*TIMED__5fOUT;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*TONER__5fEMPTY;
	struct _jc_javax_print_attribute_standard_PrinterStateReason$object	*TONER__5fLOW;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrinterStateReason;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrinterStateReason$fields_struct _jc_javax_print_attribute_standard_PrinterStateReason$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrinterStateReason$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReason$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterStateReason$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReason$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrinterStateReason$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReason$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrinterStateReason$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrinterStateReason$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_PrinterStateReason$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterStateReason$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrinterStateReason$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReason$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReason$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_PrinterStateReason$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_PrinterStateReason$vmethods	javax_print_attribute_standard_PrinterStateReason;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrinterStateReason$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrinterStateReason$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterStateReason$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterStateReason$refs {
    _jc_javax_print_attribute_standard_PrinterStateReason$sub_refs	javax_print_attribute_standard_PrinterStateReason;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterStateReason$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterStateReason$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_PrinterStateReason$sub_nonrefs	javax_print_attribute_standard_PrinterStateReason;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrinterStateReason$object {
	_jc_javax_print_attribute_standard_PrinterStateReason$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrinterStateReason$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrinterStateReason$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrinterStateReason$vtype _jc_javax_print_attribute_standard_PrinterStateReason$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrinterStateReason, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrinterStateReason$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrinterStateReason_H_ */
